//#define XERR
#include "loop.ih"

void Loop::checkSeed()
{
    switch (d_scenario.seedType())
    {
        case INCREASING_SEED:
            ++d_seed;
        [[fallthrough]];

        case FIXED_SEED:
            Random::instance().reset(d_seed);
        break;

        default:
        break;
    }
}
